.. _configaro_api:

API Docs
========

Functions
---------

- :meth:`configaro.init`
- :meth:`configaro.get`
- :meth:`configaro.put`

Errors
------

- :class:`configaro.ConfigError`
- :class:`configaro.ConfigModuleNotFoundError`
- :class:`configaro.ConfigModuleNotValidError`
- :class:`configaro.ConfigObjectNotInitializedError`
- :class:`configaro.ConfigPropertyNotFoundError`
- :class:`configaro.ConfigPropertyNotScalarError`
- :class:`configaro.ConfigUpdateNotValidError`

..  automodule:: configaro
    :members:

